==> cutefish-filemanager-0.4-2.src.tar.gz: filemanager-0.4/translations/sw.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sw">
<context>
    <name>CreateFolderDialog</name>
    <message>
        <location filename="../qml/Dialogs/CreateFolderDialog.qml" line="28"/>
        <source>New folder name</source>
        <translation>Jina la folda mpya</translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/CreateFolderDialog.qml" line="55"/>
        <source>New folder</source>
        <translation>Folda mpya</translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/CreateFolderDialog.qml" line="79"/>
        <source>Cancel</source>
        <translation>Ghairi</translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/CreateFolderDialog.qml" line="85"/>
        <source>OK</source>
        <translation>Sawa</translation>
    </message>
</context>
<context>
    <name>DateHelper</name>
    <message>
        <location filename="../helper/datehelper.cpp" line="15"/>
        <source>Now</source>
        <translation>Sasa</translation>
    </message>
    <message>
        <location filename="../helper/datehelper.cpp" line="17"/>
        <source>1 minute ago</source>
        <translation>dakika 1 imepita</translation>
    </message>
    <message>
        <location filename="../helper/datehelper.cpp" line="19"/>
        <source>%1 minutes ago</source>
        <translation>%1 dakika zimepita</translation>
    </message>
    <message>
        <location filename="../helper/datehelper.cpp" line="23"/>
        <source>1 hour ago</source>
        <translation>saa 1 imepita</translation>
    </message>
    <message>
        <location filename="../helper/datehelper.cpp" line="25"/>
        <source>%1 hours ago</source>
        <translation>masaa %1 zimepita</translation>
    </message>
    <message>
        <location filename="../helper/datehelper.cpp" line="29"/>
        <source>1 day ago</source>
        <translation>Siku 1 imepita</translation>
    </message>
    <message>
        <location filename="../helper/datehelper.cpp" line="31"/>
        <source>%1 days ago</source>
        <translation>Siku %1 zimepita</translation>
    </message>
</context>
<context>
    <name>DesktopView</name>
    <message>
        <location filename="../desktop/desktopview.cpp" line="44"/>
        <source>Desktop</source>
        <translation>Desktop</translation>
    </message>
</context>
<context>
    <name>EmptyTrashDialog</name>
    <message>
        <location filename="../qml/Dialogs/EmptyTrashDialog.qml" line="30"/>
        <source>File Manager</source>
        <translation>meneja la faili</translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/EmptyTrashDialog.qml" line="60"/>
        <source>Do you want to permanently delete all files from the Trash?</source>
        <translation>Unataka kufuta kila kitu kwa Takataka?</translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/EmptyTrashDialog.qml" line="69"/>
        <source>Cancel</source>
        <translation>Ghairi</translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/EmptyTrashDialog.qml" line="75"/>
        <source>Empty Trash</source>
        <translation>Futa Takataka</translation>
    </message>
</context>
<context>
    <name>FilePropertiesDialog</name>
    <message>
        <location filename="../dialogs/filepropertiesdialog.cpp" line="178"/>
        <source>Properties</source>
        <translation>Mali</translation>
    </message>
    <message>
        <location filename="../dialogs/filepropertiesdialog.cpp" line="226"/>
        <source>%1 files</source>
        <translation>%1 faili</translation>
    </message>
</context>
<context>
    <name>FolderModel</name>
    <message>
        <location filename="../model/foldermodel.cpp" line="168"/>
        <source>%1 item</source>
        <translation>%1 kitu</translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="168"/>
        <source>%1 items</source>
        <translation>%1 vitu</translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="892"/>
        <source>Select All</source>
        <translation>Chagua Zote</translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="1107"/>
        <source>Open</source>
        <translation>Fungua</translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="1110"/>
        <source>Open with</source>
        <translation>Fungua na</translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="1113"/>
        <source>Cut</source>
        <translation>Kata</translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="1116"/>
        <source>Copy</source>
        <translation>Nakala</translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="1119"/>
        <source>Paste</source>
        <translation>Bandika</translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="1122"/>
        <source>New Folder</source>
        <translation>Folda mpya</translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="1125"/>
        <source>Move To Trash</source>
        <translation>Weka ndani ya Takataka</translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="1128"/>
        <source>Empty Trash</source>
        <translation>Futa Takataka</translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="1131"/>
        <source>Delete</source>
        <translation>Futa</translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="1134"/>
        <source>Rename</source>
        <translation>Badilisha jina</translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="1137"/>
        <source>Open in Terminal</source>
        <translation>Fungua ndani ya Terminal</translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="1140"/>
        <source>Set as Wallpaper</source>
        <translation>Weka kama kikaratasi</translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="1143"/>
        <source>Properties</source>
        <translation>Mali</translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="1146"/>
        <source>Change background</source>
        <translation>Badilisha kikaratasi</translation>
    </message>
</context>
<context>
    <name>FolderPage</name>
    <message>
        <location filename="../qml/FolderPage.qml" line="117"/>
        <source>Empty folder</source>
        <translation>Folda tupu</translation>
    </message>
    <message>
        <location filename="../qml/FolderPage.qml" line="148"/>
        <source>Open</source>
        <translation>Fungua</translation>
    </message>
    <message>
        <location filename="../qml/FolderPage.qml" line="60"/>
        <location filename="../qml/FolderPage.qml" line="153"/>
        <source>Properties</source>
        <translation>Mali</translation>
    </message>
    <message>
        <location filename="../qml/FolderPage.qml" line="50"/>
        <source>File</source>
        <translation>Faili</translation>
    </message>
    <message>
        <location filename="../qml/FolderPage.qml" line="53"/>
        <source>New Folder</source>
        <translation>Folda mpya</translation>
    </message>
    <message>
        <location filename="../qml/FolderPage.qml" line="67"/>
        <source>Quit</source>
        <translation>Toka</translation>
    </message>
    <message>
        <location filename="../qml/FolderPage.qml" line="73"/>
        <source>Edit</source>
        <translation>Badilisha</translation>
    </message>
    <message>
        <location filename="../qml/FolderPage.qml" line="76"/>
        <source>Select All</source>
        <translation>Chagua zote</translation>
    </message>
    <message>
        <location filename="../qml/FolderPage.qml" line="82"/>
        <source>Help</source>
        <translation>Usaidizi</translation>
    </message>
    <message>
        <location filename="../qml/FolderPage.qml" line="85"/>
        <source>About</source>
        <translation>Kuhusu</translation>
    </message>
    <message>
        <location filename="../qml/FolderPage.qml" line="215"/>
        <source>%1 item</source>
        <translation>%1 kitu</translation>
    </message>
    <message>
        <location filename="../qml/FolderPage.qml" line="216"/>
        <source>%1 items</source>
        <translation>%1 vitu</translation>
    </message>
    <message>
        <location filename="../qml/FolderPage.qml" line="222"/>
        <source>%1 selected</source>
        <translation>%1 imechaguliwa</translation>
    </message>
    <message>
        <location filename="../qml/FolderPage.qml" line="233"/>
        <source>Empty Trash</source>
        <translation>Futa Takataka</translation>
    </message>
</context>
<context>
    <name>OpenWithDialog</name>
    <message>
        <location filename="../qml/Dialogs/OpenWithDialog.qml" line="70"/>
        <source>No applications</source>
        <translation>Hakuna programu</translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/OpenWithDialog.qml" line="136"/>
        <source>Set as default</source>
        <translation>Weka kama kawaida</translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/OpenWithDialog.qml" line="145"/>
        <source>Cancel</source>
        <translation>Ghairi</translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/OpenWithDialog.qml" line="154"/>
        <source>Open</source>
        <translation>Fungua</translation>
    </message>
    <message>
        <location filename="../dialogs/openwithdialog.cpp" line="32"/>
        <source>Open With</source>
        <translation>Fungua na</translation>
    </message>
</context>
<context>
    <name>OptionsMenu</name>
    <message>
        <location filename="../qml/OptionsMenu.qml" line="45"/>
        <source>Icons</source>
        <translation>Ikoni</translation>
    </message>
    <message>
        <location filename="../qml/OptionsMenu.qml" line="79"/>
        <source>List</source>
        <translation>Orodha</translation>
    </message>
    <message>
        <location filename="../qml/OptionsMenu.qml" line="115"/>
        <source>Name</source>
        <translation>Jina</translation>
    </message>
    <message>
        <location filename="../qml/OptionsMenu.qml" line="149"/>
        <source>Date</source>
        <translation>Tarehe</translation>
    </message>
    <message>
        <location filename="../qml/OptionsMenu.qml" line="183"/>
        <source>Size</source>
        <translation>Ukubwa</translation>
    </message>
</context>
<context>
    <name>PlacesModel</name>
    <message>
        <location filename="../model/placesmodel.cpp" line="39"/>
        <source>Home</source>
        <translation>Nyumbani</translation>
    </message>
    <message>
        <location filename="../model/placesmodel.cpp" line="46"/>
        <source>Desktop</source>
        <translation>Desktop</translation>
    </message>
    <message>
        <location filename="../model/placesmodel.cpp" line="53"/>
        <source>Documents</source>
        <translation>Hati</translation>
    </message>
    <message>
        <location filename="../model/placesmodel.cpp" line="60"/>
        <source>Downloads</source>
        <translation>Mapakuo</translation>
    </message>
    <message>
        <location filename="../model/placesmodel.cpp" line="67"/>
        <source>Music</source>
        <translation>Muziki</translation>
    </message>
    <message>
        <location filename="../model/placesmodel.cpp" line="74"/>
        <source>Pictures</source>
        <translation>Mapicha</translation>
    </message>
    <message>
        <location filename="../model/placesmodel.cpp" line="81"/>
        <source>Videos</source>
        <translation>Mavideo</translation>
    </message>
    <message>
        <location filename="../model/placesmodel.cpp" line="86"/>
        <source>Trash</source>
        <translation>Takataka</translation>
    </message>
</context>
<context>
    <name>PropertiesDialog</name>
    <message>
        <location filename="../qml/Dialogs/PropertiesDialog.qml" line="95"/>
        <source>Type:</source>
        <translation>Aina:</translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/PropertiesDialog.qml" line="108"/>
        <source>Location:</source>
        <translation>Mahali:</translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/PropertiesDialog.qml" line="119"/>
        <source>Size:</source>
        <translation>Ukubwa:</translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/PropertiesDialog.qml" line="126"/>
        <source>Calculating...</source>
        <translation type="unfinished">inapiga hesabu...</translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/PropertiesDialog.qml" line="130"/>
        <source>Created:</source>
        <translation>Imetengezwa:</translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/PropertiesDialog.qml" line="143"/>
        <source>Modified:</source>
        <translation>Imebadilishwa:</translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/PropertiesDialog.qml" line="156"/>
        <source>Accessed:</source>
        <translation>Imefunguliwa:</translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/PropertiesDialog.qml" line="178"/>
        <source>Cancel</source>
        <translation>Ghairi</translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/PropertiesDialog.qml" line="184"/>
        <source>OK</source>
        <translation>Sawa</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../qml/main.qml" line="35"/>
        <source>File Manager</source>
        <translation>Meneja la faili</translation>
    </message>
</context>
</TS>

==> cutefish-filemanager-0.8-2.src.tar.gz: filemanager-0.8/translations/sw.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sw">
<context>
    <name>CreateFolderDialog</name>
    <message>
        <location filename="../qml/Dialogs/CreateFolderDialog.qml" line="28"/>
        <source>New folder name</source>
        <translation>Jina la folda mpya</translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/CreateFolderDialog.qml" line="55"/>
        <source>New folder</source>
        <translation>Folda mpya</translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/CreateFolderDialog.qml" line="79"/>
        <source>Cancel</source>
        <translation>Ghairi</translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/CreateFolderDialog.qml" line="85"/>
        <source>OK</source>
        <translation>Sawa</translation>
    </message>
</context>
<context>
    <name>DateHelper</name>
    <message>
        <location filename="../helper/datehelper.cpp" line="15"/>
        <source>Now</source>
        <translation>Sasa</translation>
    </message>
    <message>
        <location filename="../helper/datehelper.cpp" line="17"/>
        <source>1 minute ago</source>
        <translation>dakika 1 imepita</translation>
    </message>
    <message>
        <location filename="../helper/datehelper.cpp" line="19"/>
        <source>%1 minutes ago</source>
        <translation>%1 dakika zimepita</translation>
    </message>
    <message>
        <location filename="../helper/datehelper.cpp" line="23"/>
        <source>1 hour ago</source>
        <translation>saa 1 imepita</translation>
    </message>
    <message>
        <location filename="../helper/datehelper.cpp" line="25"/>
        <source>%1 hours ago</source>
        <translation>masaa %1 zimepita</translation>
    </message>
    <message>
        <location filename="../helper/datehelper.cpp" line="29"/>
        <source>1 day ago</source>
        <translation>Siku 1 imepita</translation>
    </message>
    <message>
        <location filename="../helper/datehelper.cpp" line="31"/>
        <source>%1 days ago</source>
        <translation>Siku %1 zimepita</translation>
    </message>
</context>
<context>
    <name>DeleteDialog</name>
    <message>
        <location filename="../qml/Dialogs/DeleteDialog.qml" line="47"/>
        <source>Do you want to delete it permanently?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/DeleteDialog.qml" line="56"/>
        <source>Cancel</source>
        <translation type="unfinished">Ghairi</translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/DeleteDialog.qml" line="62"/>
        <source>Delete</source>
        <translation type="unfinished">Futa</translation>
    </message>
</context>
<context>
    <name>DesktopView</name>
    <message>
        <location filename="../desktop/desktopview.cpp" line="44"/>
        <source>Desktop</source>
        <translation>Desktop</translation>
    </message>
</context>
<context>
    <name>EmptyTrashDialog</name>
    <message>
        <location filename="../qml/Dialogs/EmptyTrashDialog.qml" line="30"/>
        <source>File Manager</source>
        <translation>meneja la faili</translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/EmptyTrashDialog.qml" line="60"/>
        <source>Do you want to permanently delete all files from the Trash?</source>
        <translation>Unataka kufuta kila kitu kwa Takataka?</translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/EmptyTrashDialog.qml" line="69"/>
        <source>Cancel</source>
        <translation>Ghairi</translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/EmptyTrashDialog.qml" line="75"/>
        <source>Empty Trash</source>
        <translation>Futa Takataka</translation>
    </message>
</context>
<context>
    <name>FilePropertiesDialog</name>
    <message>
        <location filename="../dialogs/filepropertiesdialog.cpp" line="179"/>
        <source>Properties</source>
        <translation>Mali</translation>
    </message>
    <message>
        <location filename="../dialogs/filepropertiesdialog.cpp" line="227"/>
        <source>%1 files</source>
        <translation>%1 faili</translation>
    </message>
</context>
<context>
    <name>FolderModel</name>
    <message>
        <location filename="../model/foldermodel.cpp" line="184"/>
        <source>%1 item</source>
        <translation>%1 kitu</translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="184"/>
        <source>%1 items</source>
        <translation>%1 vitu</translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="249"/>
        <source>The file or folder %1 does not exist.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="981"/>
        <source>Select All</source>
        <translation>Chagua Zote</translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="1088"/>
        <source>File Manager</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="1281"/>
        <source>Open</source>
        <translation>Fungua</translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="1284"/>
        <source>Open with</source>
        <translation>Fungua na</translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="1287"/>
        <source>Cut</source>
        <translation>Kata</translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="1290"/>
        <source>Copy</source>
        <translation>Nakala</translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="1293"/>
        <source>Paste</source>
        <translation>Bandika</translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="1296"/>
        <source>New Folder</source>
        <translation>Folda mpya</translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="1299"/>
        <source>Move To Trash</source>
        <translation>Weka ndani ya Takataka</translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="1302"/>
        <source>Empty Trash</source>
        <translation>Futa Takataka</translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="1305"/>
        <source>Delete</source>
        <translation>Futa</translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="1308"/>
        <source>Rename</source>
        <translation>Badilisha jina</translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="1311"/>
        <source>Open in Terminal</source>
        <translation>Fungua ndani ya Terminal</translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="1314"/>
        <source>Set as Wallpaper</source>
        <translation>Weka kama kikaratasi</translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="1317"/>
        <source>Properties</source>
        <translation>Mali</translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="1320"/>
        <source>Change background</source>
        <translation>Badilisha kikaratasi</translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="1323"/>
        <source>Restore</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FolderPage</name>
    <message>
        <location filename="../qml/FolderPage.qml" line="134"/>
        <source>Empty folder</source>
        <translation>Folda tupu</translation>
    </message>
    <message>
        <location filename="../qml/FolderPage.qml" line="174"/>
        <source>Open</source>
        <translation>Fungua</translation>
    </message>
    <message>
        <location filename="../qml/FolderPage.qml" line="60"/>
        <location filename="../qml/FolderPage.qml" line="179"/>
        <source>Properties</source>
        <translation>Mali</translation>
    </message>
    <message>
        <location filename="../qml/FolderPage.qml" line="50"/>
        <source>File</source>
        <translation>Faili</translation>
    </message>
    <message>
        <location filename="../qml/FolderPage.qml" line="53"/>
        <source>New Folder</source>
        <translation>Folda mpya</translation>
    </message>
    <message>
        <location filename="../qml/FolderPage.qml" line="67"/>
        <source>Quit</source>
        <translation>Toka</translation>
    </message>
    <message>
        <location filename="../qml/FolderPage.qml" line="73"/>
        <source>Edit</source>
        <translation>Badilisha</translation>
    </message>
    <message>
        <location filename="../qml/FolderPage.qml" line="76"/>
        <source>Select All</source>
        <translation>Chagua zote</translation>
    </message>
    <message>
        <location filename="../qml/FolderPage.qml" line="83"/>
        <source>Cut</source>
        <translation type="unfinished">Kata</translation>
    </message>
    <message>
        <location filename="../qml/FolderPage.qml" line="88"/>
        <source>Copy</source>
        <translation type="unfinished">Nakala</translation>
    </message>
    <message>
        <location filename="../qml/FolderPage.qml" line="93"/>
        <source>Paste</source>
        <translation type="unfinished">Bandika</translation>
    </message>
    <message>
        <location filename="../qml/FolderPage.qml" line="99"/>
        <source>Help</source>
        <translation>Usaidizi</translation>
    </message>
    <message>
        <location filename="../qml/FolderPage.qml" line="102"/>
        <source>About</source>
        <translation>Kuhusu</translation>
    </message>
    <message>
        <location filename="../qml/FolderPage.qml" line="241"/>
        <source>%1 item</source>
        <translation>%1 kitu</translation>
    </message>
    <message>
        <location filename="../qml/FolderPage.qml" line="242"/>
        <source>%1 items</source>
        <translation>%1 vitu</translation>
    </message>
    <message>
        <location filename="../qml/FolderPage.qml" line="248"/>
        <source>%1 selected</source>
        <translation>%1 imechaguliwa</translation>
    </message>
    <message>
        <location filename="../qml/FolderPage.qml" line="259"/>
        <source>Empty Trash</source>
        <translation>Futa Takataka</translation>
    </message>
</context>
<context>
    <name>OpenWithDialog</name>
    <message>
        <location filename="../qml/Dialogs/OpenWithDialog.qml" line="78"/>
        <source>No applications</source>
        <translation>Hakuna programu</translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/OpenWithDialog.qml" line="142"/>
        <source>Set as default</source>
        <translation>Weka kama kawaida</translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/OpenWithDialog.qml" line="151"/>
        <source>Cancel</source>
        <translation>Ghairi</translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/OpenWithDialog.qml" line="160"/>
        <source>Open</source>
        <translation>Fungua</translation>
    </message>
    <message>
        <location filename="../dialogs/openwithdialog.cpp" line="32"/>
        <source>Open With</source>
        <translation>Fungua na</translation>
    </message>
</context>
<context>
    <name>OptionsMenu</name>
    <message>
        <location filename="../qml/OptionsMenu.qml" line="47"/>
        <source>Icons</source>
        <translation>Ikoni</translation>
    </message>
    <message>
        <location filename="../qml/OptionsMenu.qml" line="85"/>
        <source>List</source>
        <translation>Orodha</translation>
    </message>
    <message>
        <location filename="../qml/OptionsMenu.qml" line="127"/>
        <source>Name</source>
        <translation>Jina</translation>
    </message>
    <message>
        <location filename="../qml/OptionsMenu.qml" line="165"/>
        <source>Date</source>
        <translation>Tarehe</translation>
    </message>
    <message>
        <location filename="../qml/OptionsMenu.qml" line="189"/>
        <source>Type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/OptionsMenu.qml" line="227"/>
        <source>Size</source>
        <translation>Ukubwa</translation>
    </message>
</context>
<context>
    <name>PlacesModel</name>
    <message>
        <location filename="../model/placesmodel.cpp" line="39"/>
        <source>Home</source>
        <translation>Nyumbani</translation>
    </message>
    <message>
        <location filename="../model/placesmodel.cpp" line="47"/>
        <source>Desktop</source>
        <translation>Desktop</translation>
    </message>
    <message>
        <location filename="../model/placesmodel.cpp" line="55"/>
        <source>Documents</source>
        <translation>Hati</translation>
    </message>
    <message>
        <location filename="../model/placesmodel.cpp" line="63"/>
        <source>Downloads</source>
        <translation>Mapakuo</translation>
    </message>
    <message>
        <location filename="../model/placesmodel.cpp" line="71"/>
        <source>Music</source>
        <translation>Muziki</translation>
    </message>
    <message>
        <location filename="../model/placesmodel.cpp" line="79"/>
        <source>Pictures</source>
        <translation>Mapicha</translation>
    </message>
    <message>
        <location filename="../model/placesmodel.cpp" line="87"/>
        <source>Videos</source>
        <translation>Mavideo</translation>
    </message>
    <message>
        <location filename="../model/placesmodel.cpp" line="93"/>
        <source>Trash</source>
        <translation>Takataka</translation>
    </message>
    <message>
        <location filename="../model/placesmodel.cpp" line="117"/>
        <location filename="../model/placesmodel.cpp" line="265"/>
        <source>Drives</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PropertiesDialog</name>
    <message>
        <location filename="../qml/Dialogs/PropertiesDialog.qml" line="94"/>
        <source>Type:</source>
        <translation>Aina:</translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/PropertiesDialog.qml" line="107"/>
        <source>Location:</source>
        <translation>Mahali:</translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/PropertiesDialog.qml" line="118"/>
        <source>Size:</source>
        <translation>Ukubwa:</translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/PropertiesDialog.qml" line="125"/>
        <source>Calculating...</source>
        <translation type="unfinished">inapiga hesabu...</translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/PropertiesDialog.qml" line="129"/>
        <source>Created:</source>
        <translation>Imetengezwa:</translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/PropertiesDialog.qml" line="142"/>
        <source>Modified:</source>
        <translation>Imebadilishwa:</translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/PropertiesDialog.qml" line="155"/>
        <source>Accessed:</source>
        <translation>Imefunguliwa:</translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/PropertiesDialog.qml" line="177"/>
        <source>Cancel</source>
        <translation>Ghairi</translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/PropertiesDialog.qml" line="183"/>
        <source>OK</source>
        <translation>Sawa</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../qml/main.qml" line="35"/>
        <source>File Manager</source>
        <translation>Meneja la faili</translation>
    </message>
</context>
</TS>
